@@ -77,23 +77,21 @@ class ConfigBuilder:
         redis_port = os.getenv("REDIS_PORT")
         sentinel_mode = True if os.getenv("REDIS_SENTINEL", "False") == "True" else False  # type: ignore
 
-        cls.broker_url = f"amqp://{amqp_user}:{amqp_pass}@{amqp_broker}:{amqp_port}/"
-        cls.result_backend = (
-            f"{'sentinel' if sentinel_mode else 'redis'}://{redis_host}:{redis_port}"
-        )
+        if any([amqp_broker, amqp_port, amqp_user, amqp_pass]):
+            cls.broker_url = f"amqp://{amqp_user}:{amqp_pass}@{amqp_broker}:{amqp_port}/"
+
+        if any([redis_host, redis_port]):
+            cls.result_backend = (
+                f"{'sentinel' if sentinel_mode else 'redis'}://{redis_host}:{redis_port}"
+            )
+
         cls.sentinel_mode = sentinel_mode
 
         return cls.__build_config(
             es_url=es_url or cls.es_url,
             es_username=es_username,
             es_password=es_password,
-            broker_url=(
-                f"amqp://{amqp_user}:{amqp_pass}@{amqp_broker}:{amqp_port}/"
-                or cls.broker_url
-            ),
-            result_backend=(
-                f"{'sentinel' if sentinel_mode else 'redis'}://{redis_host}:{redis_port}"
-                or cls.result_backend
-            ),
+            broker_url=cls.broker_url,
+            result_backend=cls.result_backend,
             sentinel_mode=sentinel_mode or cls.sentinel_mode,
         )
