@@ -1,4 +1,5 @@
 from enum import Enum
+from typing import List
 
 
 class LoggerInstances(Enum):
@@ -7,6 +8,16 @@ class LoggerInstances(Enum):
     SCHEDULER = "scheduler"
     OTHER = "other"
 
+    @classmethod
+    def keys(cls) -> List[str]:
+        """Returns a list of all the enum keys."""
+        return cls._member_names_
+
+    @classmethod
+    def values(cls) -> List[str]:
+        """Returns a list of all the enum values."""
+        return list(cls._value2member_map_.keys())
+
     @classmethod
     def has_value(cls, key) -> bool:
         return isinstance(key, cls) or key.upper() in cls.__members__
