@@ -1,11 +1,12 @@
 import logging
 from typing import List, Optional, Union
 
+from colorlog import ColoredFormatter
+
 from loralogger.handlers import LogToESHandler
 from loralogger.instances import LoggerInstances
 from loralogger.loggers.logger import LoraLoggerClass
 
-
 # adapted from https://dock2learn.com/tech/create-a-reusable-logger-factory-for-python-projects/
 
 
@@ -20,10 +21,12 @@ class LoraLogger:
         log_to_console: bool = False,
         log_to_syslog: bool = False,
         skip_queue: bool = False,
+        use_colors: bool = False,
     ) -> LoraLoggerClass:
         logger_name: str = label or "loralogger"
 
         logger_format: str = format or "| %(levelname)-9s | %(asctime)s | %(message)s"
+        logger_style: str = "%"
         date_format = date_format or "%Y-%m-%dT%H:%M:%S"
 
         logger_level: str = level or "DEBUG"
@@ -45,10 +48,34 @@ class LoraLogger:
 
         if log_to_es:
             es_handlers = LogToESHandler(logger_name, skip_queue)
+
+            formatter = logging.Formatter(fmt=logger_format, datefmt=date_format)
+            es_handlers.setFormatter(formatter)
+
             logger_handlers.append(es_handlers)
 
         if log_to_console:
             console_handler = logging.StreamHandler()
+
+            if use_colors:
+                logger_format = "{log_color} {levelname:^9}{reset} {asctime}\n{message}\n{log_color} END LOG  {reset}"
+                logger_style = "{"
+
+            formatter = ColoredFormatter(
+                logger_format,
+                datefmt=date_format,
+                reset=True,
+                log_colors={
+                    "DEBUG": "black,bg_cyan",
+                    "INFO": "black,bg_green",
+                    "WARNING": "black,bg_yellow",
+                    "ERROR": "black,bg_red",
+                    "CRITICAL": "red,bg_white",
+                },
+                style=logger_style,
+            )
+            console_handler.setFormatter(formatter)
+
             logger_handlers.append(console_handler)
 
         if log_to_syslog:
@@ -64,9 +91,6 @@ class LoraLogger:
 
         # Add handlers for it, including the log format
         for handler in logger_handlers:
-            formatter = logging.Formatter(fmt=logger_format, datefmt=date_format)
-            handler.setFormatter(formatter)
-
             logger.addHandler(handler)
 
         return logger  # type: ignore
@@ -78,9 +102,10 @@ class LoraLogger:
         date_format: Optional[str] = None,
         level: Optional[str] = None,
         log_to_es: bool = True,
-        log_to_console: bool = False,
+        log_to_console: bool = True,
         log_to_syslog: bool = False,
         skip_queue: bool = False,
+        use_colors: bool = False,
     ) -> LoraLoggerClass:
         """Static method to generate a logger with specific label and format.
 
@@ -93,6 +118,7 @@ class LoraLogger:
             log_to_console (bool, optional): also log to console. Defaults to False.
             log_to_syslog (bool, optional): also log to syslog. Defaults to False.
             skip_queue (bool, optional): skip the logger from sending to RabbitMQ and send logs directly to ES instance
+            use_colors (bool, optional): Whether to use colors on the log messages
 
         Returns:
             LoraLoggerClass: Lora's custom logger instance
@@ -112,6 +138,7 @@ class LoraLogger:
             log_to_console,
             log_to_syslog,
             skip_queue,
+            use_colors,
         )
 
         return logger
